import React from 'react';
import styled, { css } from 'styled-components';
import { useId } from '../../hooks/useId';
import { useTheme } from '../../hooks/useTheme';
import { FaExclamationCircleIcon } from '../Icon';
import { Input } from '../Input';
import { Stack } from '../Layout/Stack';
import { StatusLabel } from '../StatusLabel';
import { Text } from '../Text';
import { useClassNames } from './useClassNames';
/**
 * @deprecated `Fieldset` コンポーネントは非推奨です。代わりに `FormControl` を使ってください。
 */
export const FieldSet = ({ label, labelType = 'subBlockTitle', errorMessage, helpMessage, className = '', labelSuffix, children, ...props }) => {
    const theme = useTheme();
    const managedHtmlFor = useId();
    const helpId = useId();
    const classNames = useClassNames();
    return (React.createElement(Wrapper, { "$width": props.width || 'auto', className: `${className} ${classNames.wrapper}`, "aria-describedby": helpMessage ? helpId : undefined },
        React.createElement(Title, { themes: theme, className: classNames.title },
            React.createElement(LabelText, { styleType: labelType, className: classNames.titleText }, label),
            props.required && (React.createElement(StatusLabel, { type: "red", className: classNames.label }, "\u5FC5\u9808")),
            labelSuffix && labelSuffix),
        helpMessage && (React.createElement(HelpMessage, { themes: theme, id: helpId, className: classNames.help }, helpMessage)),
        errorMessage && (React.createElement(StyledStack, { "$themes": theme, gap: 0, id: `${managedHtmlFor}_errorMessages` }, (Array.isArray(errorMessage) ? errorMessage : [errorMessage]).map((message, index) => (React.createElement(ErrorMessage, { themes: theme, key: index, className: classNames.error },
            React.createElement(FaExclamationCircleIcon, { text: message, className: classNames.errorText })))))),
        children ? (children) : (
        // eslint-disable-next-line smarthr/a11y-input-has-name-attribute, smarthr/a11y-input-in-form-control
        React.createElement(Input, { ...props, error: !!errorMessage, className: classNames.input }))));
};
const Wrapper = styled.div `
  ${({ $width }) => css `
    display: inline-block;
    width: ${typeof $width === 'number' ? `${$width}px` : $width};
  `}
`;
const Title = styled.div `
  ${({ themes: { spacingByChar } }) => css `
    display: flex;
    align-items: center;
    margin: 0 0 ${spacingByChar(0.5)};

    > *:not(:first-child) {
      margin-left: ${spacingByChar(0.5)};
    }
  `}
`;
const LabelText = styled(Text) `
  display: inline-block;
`;
const HelpMessage = styled.p `
  ${({ themes: { spacingByChar } }) => css `
    margin-bottom: ${spacingByChar(0.5)};
  `}
`;
const StyledStack = styled(Stack) `
  ${({ $themes: { spacingByChar } }) => css `
    &&& {
      margin-bottom: ${spacingByChar(0.5)};
    }
  `}
`;
const ErrorMessage = styled.p `
  ${({ themes: { color } }) => css `
    .smarthr-ui-FieldSet-errorText {
      color: ${color.DANGER};
    }
  `}
`;
//# sourceMappingURL=FieldSet.js.map