import React, { forwardRef, useMemo } from 'react';
import { tv } from 'tailwind-variants';
import { CheckBox } from '../CheckBox';
import { Center } from '../Layout';
import { VisuallyHiddenText } from '../VisuallyHiddenText';
import { Th } from './Th';
const CHECK_ALL_INVISIBLE_LABEL = 'すべての行を選択';
const thCheckbox = tv({
    slots: {
        inner: 'shr-absolute shr-inset-0 [&:not(:has([disabled]))]:shr-cursor-pointer',
        wrapper: 'shr-relative shr-w-[theme(fontSize.base)] [&]:shr-px-0.75',
    },
});
export const ThCheckbox = forwardRef(({ decorators, className, ...others }, ref) => {
    const { wrapperStyle, innerStyle } = useMemo(() => {
        const { wrapper, inner } = thCheckbox();
        return {
            wrapperStyle: wrapper({ className }),
            innerStyle: inner(),
        };
    }, [className]);
    return (
    // Th に必要な属性やイベントは不要
    React.createElement(Th, { className: wrapperStyle },
        React.createElement(Center, { as: "label", verticalCentering: true, className: innerStyle },
            React.createElement(CheckBox, { ...others, ref: ref }),
            React.createElement(VisuallyHiddenText, null, decorators?.checkAllInvisibleLabel?.(CHECK_ALL_INVISIBLE_LABEL) ||
                CHECK_ALL_INVISIBLE_LABEL))));
});
//# sourceMappingURL=ThCheckbox.js.map