"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Switch = void 0;
const react_1 = __importStar(require("react"));
const styled_components_1 = __importStar(require("styled-components"));
const useTheme_1 = require("../../hooks/useTheme");
const Icon_1 = require("../Icon");
exports.Switch = (0, react_1.forwardRef)(({ disabled, className, ...props }, ref) => {
    const theme = (0, useTheme_1.useTheme)();
    return (react_1.default.createElement(Wrapper, { "$disabled": disabled, themes: theme, className: className },
        react_1.default.createElement(CheckboxInput, { ...props, disabled: disabled, type: "checkbox", role: "switch", ref: ref }),
        react_1.default.createElement(CheckIcon, { "$themes": theme })));
});
const Wrapper = styled_components_1.default.span `
  ${({ $disabled, themes: { border, color, fontSize, radius, shadow } }) => (0, styled_components_1.css) `
    position: relative;
    display: inline-flex;
    align-items: center;
    border-radius: calc(${fontSize.M} * 1.25);
    border: ${border.shorthand};
    background-color: ${color.WHITE};

    /* 理想的には padding: 2px; だが、box-shadow を outline で使用しているため、border と padding で2pxの疑似余白を作っている。 */
    padding: 1px;

    /* :focus-visible-within の代替 */
    &:has(:focus-visible) {
      ${shadow.focusIndicatorStyles}
    }

    ::before,
    ::after {
      content: '';
      box-sizing: border-box;
      display: inline-block;
      border-radius: ${radius.full};
      border: ${border.shorthand};
      border-color: ${color.GREY_30};
      background-color: ${color.GREY_30};
      block-size: ${fontSize.M};
      inline-size: ${fontSize.M};
      transition-property: transform, scale;
      transition-duration: 150ms;
      transition-timing-function: ease-out;
    }

    ::before {
      scale: ${2 / 3};
    }

    /* ツマミが移動する余白のために存在している */
    ::after {
      visibility: hidden;
    }

    &:has(:checked) {
      border-color: ${color.MAIN};
      background-color: ${color.MAIN};

      ::before {
        scale: unset;
        transform: translateX(${fontSize.M});
        border-color: ${color.BORDER};
        background-color: ${color.WHITE};
      }
    }

    ${$disabled &&
    (0, styled_components_1.css) `
      &&& {
        cursor: unset;
        border-color: ${color.BORDER};
        background-color: ${color.BORDER};
      }
    `}

    @media (forced-colors: active) {
      ${$disabled
    ? (0, styled_components_1.css) `
            &&& {
              border-color: GrayText;

              &::before,
              &::after {
                border-color: GrayText;
              }
            }
          `
    : (0, styled_components_1.css) `
            /* ツマミを塗りつぶす https://developer.mozilla.org/en-US/docs/Web/CSS/system-color */
            &&&::before,
            &&&::after {
              background-color: ButtonBorder;
            }
          `}
    }

    @supports not selector(:has(+ *)) {
      border-style: revert;
      background-color: revert;

      ::before,
      ::after {
        display: none;
      }

      ${$disabled &&
    (0, styled_components_1.css) `
        &&& {
          background-color: revert;
        }
      `}
    }
  `}
`;
const CheckboxInput = styled_components_1.default.input `
  position: absolute;
  inset: 0;
  cursor: pointer;
  outline: none;
  opacity: 0;
  appearance: none;

  /* 古い iOS など inset が効かない環境で領域いっぱいに広げる */
  @supports not (inset: 0) {
    width: 100%;
    height: 100%;
  }

  :disabled {
    cursor: revert;
  }

  @supports not selector(:has(+ *)) {
    position: revert;
    opacity: revert;
    outline: revert;
    appearance: revert;
  }
`;
const CheckIcon = (0, styled_components_1.default)(Icon_1.FaCheckIcon).attrs({ color: 'WHITE', size: 'XXS' }) `
  ${({ $themes: { fontSize } }) => (0, styled_components_1.css) `
    position: absolute;
    display: none;

    @supports selector(:has(+ *)) {
      [type='checkbox']:checked ~ & {
        display: unset;
        transform: translateX(calc((${fontSize.M} - ${fontSize.XXS}) / 2));
        pointer-events: none;
      }
    }

    /* 強制カラーモードの時に状態を判別するため */
    @media (forced-colors: active) {
      fill: ButtonText;

      [type='checkbox']:disabled ~ & {
        fill: GrayText;
      }
    }
  `}
`;
//# sourceMappingURL=Switch.js.map